@@ -188,14 +188,28 @@ class BaseModeler(object):
         return LambdaLR(optimizer, lr_lambda, last_epoch)
 
     @abstractmethod
-    def _train_batch(self, batch):
-        """定义model调用方式
+    def train_batch(self, batch):
+        """输入batch， 返回模型训练结果
         :param batch: DataLoader返回的batch
         :return: outputs. list, whose first element must be loss
         """
-        pass
+        self.model.train()
+        batch = tuple(t.to(self.model.device) for t in batch)
+        return self.model(*batch)
 
-    def _set_seed(self, seed):
+    @abstractmethod
+    def predict_batch(self, batch):
+        """输入batch，返回模型预测结果
+        :param batch:
+        :return: outputs, list
+        """
+        self.model.eval()
+        batch = tuple(t.to(self.model.device) for t in batch)
+        with torch.no_grad():
+            outputs = self.model(*batch)
+            return outputs
+
+    def set_seed(self, seed):
         """设置随机数种子，可以保证运行结果可以复现
         :param seed:
         :return:
@@ -219,16 +233,14 @@ class BaseModeler(object):
         tb_writer = torch.utils.tensorboard.SummaryWriter()
 
         # added here for reproducibility
-        self._set_seed(seed)
+        self.set_seed(seed)
         self.model.zero_grad()
         global_step = 0
         tr_loss, logging_loss = 0.0, 0.0
         for _ in trange(num_epochs):
             epoch_iterator = tqdm(data_loader, desc='Iteration')
             for step, batch in enumerate(epoch_iterator):
-                self.model.train()
-                batch = tuple(t.to(self.model.device) for t in batch)
-                outputs = self._train_batch(batch)
+                outputs = self.train_batch(batch)
                 loss = outputs[0]
                 loss.backward()
 
@@ -260,10 +272,12 @@ class BaseModeler(object):
         self.model.save_pretrained(output_dir)
         return global_step, tr_loss / global_step
 
+    @abstractmethod
     def evaluate(self, data_loader, examples, features, **kwargs):
         """ 评估模型效果，输出DataFrame结果以供指标评估 """
-        raise NotImplementedError
+        pass
 
+    @abstractmethod
     def predict(self, examples, features, data_loader=None, **kwargs):
         """ 预测结果，输出DataFrame结果以供预览，用于批量预测
         :param examples: list of Examples
@@ -272,7 +286,7 @@ class BaseModeler(object):
             construct one batch data_loader to predict examples
         :param kwargs:
         """
-        raise NotImplementedError
+        pass
 
     def predict_items(self, items, processor, **kwargs):
         """ 预测结果，输出DataFrame结果以供指标评估，用于在线预测
